@@ -1,7 +1,7 @@
 /*
  *  eventmodel.cpp  -  model containing flat list of events
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2007-2023 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2025 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -258,8 +258,15 @@ void AlarmListModel::setEventTypeFilter(CalEvent::Types types)
     if (this != mAllInstance
     &&  types != mFilterTypes)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        beginFilterChange();
+#endif
         mFilterTypes = types;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
         invalidateFilter();
+#endif
     }
 }
 
@@ -334,6 +341,7 @@ bool AlarmListModel::filterAcceptsRow(int sourceRow, const QModelIndex& sourcePa
         {
             // Determine whether this event is included in the date filter,
             // and cache its status.
+            KADateTime endDateTime = mFilterDates.constLast().second;
             KADateTime occurs;
             for (int i = 0, count = mFilterDates.size();  i < count && !occurs.isValid();  ++i)
             {
@@ -342,7 +350,7 @@ bool AlarmListModel::filterAcceptsRow(int sourceRow, const QModelIndex& sourcePa
                 while (!occurs.isValid())
                 {
                     DateTime nextDt;
-                    ev.nextOccurrence(from, nextDt, KAEvent::Repeats::Return);
+                    ev.nextDateTime(from, nextDt, (KAEvent::NextRepeat | KAEvent::NextWorkHoliday), endDateTime);
                     if (!nextDt.isValid())
                     {
                         resourceHash[ev.id()] = KADateTime();
@@ -368,12 +376,8 @@ bool AlarmListModel::filterAcceptsRow(int sourceRow, const QModelIndex& sourcePa
                         }
                     }
                     // It lies in this date range.
-                    if (!ev.excludedByWorkTimeOrHoliday(from))
-                    {
-                        occurs = from;
-                        break;    // event occurs in this date range
-                    }
-                    // This occurrence is excluded, so check for another.
+                    occurs = from;
+                    break;    // event occurs in this date range
                 }
             }
             resourceHash[ev.id()] = occurs;
@@ -565,8 +569,15 @@ void TemplateListModel::setAlarmActionFilter(KAEvent::Action types)
     // Ensure that the filter isn't applied to the 'all' instance.
     if (this != mAllInstance  &&  types != mActionsFilter)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        beginFilterChange();
+#endif
         mActionsFilter = types;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
         invalidateFilter();
+#endif
     }
 }
 
@@ -575,8 +586,15 @@ void TemplateListModel::setAlarmActionsEnabled(KAEvent::Action types)
     // Ensure that the setting isn't applied to the 'all' instance.
     if (this != mAllInstance  &&  types != mActionsEnabled)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        beginFilterChange();
+#endif
         mActionsEnabled = types;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
         invalidateFilter();
+#endif
     }
 }
 
